..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".


..  shortname:: Plan10
..  description:: Worked examples plus practice for Plan 10.

.. _plan_10:

Plan 10: Store info in a json file
####################################

Plan 10: Outline
====================================

.. image:: _static/plan10outline.png
    :scale: 90%
    :align: center
    :alt: Plan 10 outline
